.. warning::
    Client version 2 is obsolete, please use Client version 3 instead.


Handlers
========

Project
-------
.. autoclass:: copr.client_v2.handlers.ProjectHandle
   :members:

Project chroot
--------------
.. autoclass:: copr.client_v2.handlers.ProjectChrootHandle
   :members:


Build
-----
.. autoclass:: copr.client_v2.handlers.BuildHandle
   :members:

Build task
----------

.. autoclass:: copr.client_v2.handlers.BuildTaskHandle
   :members:


Mock chroot
-----------
.. autoclass:: copr.client_v2.handlers.MockChrootHandle
   :members:
